@@ -5,7 +5,8 @@ BASE_URLS = {
     "PONS": "https://en.pons.com/translate/",
     "YANDEX": "https://translate.yandex.net/api/{version}/tr.json/{endpoint}",
     "LINGUEE": "https://www.linguee.com/",
-    "MYMEMORY": "http://api.mymemory.translated.net/get"
+    "MYMEMORY": "http://api.mymemory.translated.net/get",
+    "QCRI": "https://mt.qcri.org/api/v1/{endpoint}?"
 }
 
 GOOGLE_CODES_TO_LANGUAGES = {
@@ -177,3 +178,5 @@ LINGUEE_LANGUAGES_TO_CODES = {
 }
 
 LINGUEE_CODE_TO_LANGUAGE = {v: k for k, v in LINGUEE_LANGUAGES_TO_CODES.items()}
+
+# "72e9e2cc7c992db4dcbdd6fb9f91a0d1"
